==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_pl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=pl
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_effacer_statistiques' => 'Effacer les statistiques', # MODIF

	// I
	'icone_evolution_visites' => 'Rozwój wizyt<br />@visites@ wizyt',
	'icone_repartition_actuelle' => 'Pokaż aktualną dystrybucję',
	'icone_repartition_visites' => 'Rozłożenie wizyt',
	'icone_statistiques_visites' => 'Statystyki',
	'info_affichier_visites_articles_plus_visites' => 'Pokaż odwiedziny dla <b>najczęściej odwiedzanych artykułów od początku:</b>',
	'info_comment_lire_tableau' => 'Jak odczytywac tą tabelę',
	'info_forum_statistiques' => 'Odwiedź statystyki',
	'info_popularite_2' => 'popularność strony:',
	'info_popularite_3' => 'popularność: @popularite@; odwiedziny: @visites@',
	'info_popularite_5' => 'popularność:',
	'info_visites' => 'odwiedziny:',
	'info_visites_plus_populaires' => 'Pokaż odwiedziny dla <b>najpopularniejszych artykułów</b> i dla <b>artykułów ostatnio opublikowanych:</b>',
	'info_zoom' => 'zoom',
	'item_gerer_statistiques' => 'Zarządzaj statystykami', # MODIF

	// O
	'onglet_origine_visites' => 'Wizyty z URL-i',
	'onglet_repartition_debut' => 'od początku',
	'onglet_repartition_lang' => 'Porządkowanie wg języków',

	// R
	'resume' => 'Resume', # MODIF

	// T
	'texte_comment_lire_tableau' => 'Szereg artykułów występujących, w klasyfikacji popularności jest na marginesie marge ; popularność artykułu(szacunek dziennej liczby wizyt zostanie obiczony jeśli częstotliwość wizyt zostanie utrzymana) a liczba wizyt, od początku opublikowania artykułu pojawi się kiedy najedziesz myszką na tytuł artykułu.',
	'texte_signification' => 'Ciemne paski oznaczają podsumowanie wszystkich odwiedzin w poddziałach, paski jasne liczbę wizyt dla poszczególnych działów.',
	'titre_evolution_visite' => 'Ewolucja odwiedzin',
	'titre_liens_entrants' => 'Linki wejściowe',
	'titre_page_statistiques' => 'Statystyki działu',
	'titre_page_statistiques_visites' => 'Statystyka odwiedzin'
);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_pl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=pl
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_effacer_statistiques' => 'Effacer les statistiques', # MODIF

	// I
	'icone_evolution_visites' => 'Rozwój wizyt<br />@visites@ wizyt',
	'icone_repartition_actuelle' => 'Pokaż aktualną dystrybucję',
	'icone_repartition_visites' => 'Rozłożenie wizyt',
	'icone_statistiques_visites' => 'Statystyki',
	'info_affichier_visites_articles_plus_visites' => 'Pokaż odwiedziny dla <b>najczęściej odwiedzanych artykułów od początku:</b>',
	'info_comment_lire_tableau' => 'Jak odczytywac tą tabelę',
	'info_forum_statistiques' => 'Odwiedź statystyki',
	'info_popularite_2' => 'popularność strony:',
	'info_popularite_3' => 'popularność: @popularite@; odwiedziny: @visites@',
	'info_popularite_5' => 'popularność:',
	'info_visites' => 'odwiedziny:',
	'info_visites_plus_populaires' => 'Pokaż odwiedziny dla <b>najpopularniejszych artykułów</b> i dla <b>artykułów ostatnio opublikowanych:</b>',
	'info_zoom' => 'zoom',
	'item_gerer_statistiques' => 'Zarządzaj statystykami', # MODIF

	// O
	'onglet_origine_visites' => 'Wizyty z URL-i',
	'onglet_repartition_debut' => 'od początku',
	'onglet_repartition_lang' => 'Porządkowanie wg języków',

	// R
	'resume' => 'Resume', # MODIF

	// T
	'texte_comment_lire_tableau' => 'Szereg artykułów występujących, w klasyfikacji popularności jest na marginesie marge ; popularność artykułu(szacunek dziennej liczby wizyt zostanie obiczony jeśli częstotliwość wizyt zostanie utrzymana) a liczba wizyt, od początku opublikowania artykułu pojawi się kiedy najedziesz myszką na tytuł artykułu.',
	'texte_signification' => 'Ciemne paski oznaczają podsumowanie wszystkich odwiedzin w poddziałach, paski jasne liczbę wizyt dla poszczególnych działów.',
	'titre_evolution_visite' => 'Ewolucja odwiedzin',
	'titre_liens_entrants' => 'Linki wejściowe',
	'titre_page_statistiques' => 'Statystyki działu',
	'titre_page_statistiques_visites' => 'Statystyka odwiedzin',
];
